package org.foxarmy.barcodescannerforemployees

//import com.google.mlkit.vision.codescanner.GmsBarcodeScannerOptions
import android.app.Activity
import android.content.Intent
import android.graphics.Bitmap
import android.os.Bundle
import android.provider.MediaStore
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.activity.result.contract.ActivityResultContracts
import androidx.fragment.app.Fragment
import com.google.mlkit.vision.barcode.common.Barcode
import com.google.mlkit.vision.codescanner.GmsBarcodeScannerOptions
import com.google.mlkit.vision.codescanner.GmsBarcodeScanning
import org.foxarmy.barcodescannerforemployees.databinding.AddProductFragmentBinding
import java.io.File
import java.io.FileOutputStream
import java.nio.ByteBuffer
import java.security.MessageDigest


@OptIn(ExperimentalStdlibApi::class)
fun String.md5(): String {
    val md = MessageDigest.getInstance("MD5")
    val digest = md.digest(this.toByteArray())
    return digest.toHexString()
}

/**
 * A simple [Fragment] subclass as the default destination in the navigation.
 */

class AddProductFragment : Fragment() {

    private var _binding: AddProductFragmentBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {

        _binding = AddProductFragmentBinding.inflate(inflater, container, false)
        return binding.root

    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        when (requestCode) {
            200 -> {
                if (resultCode == Activity.RESULT_OK && data != null) {
                    val picture = (data.extras?.get("data") as Bitmap)
                    binding.imageView.setImageBitmap(picture)
                    val picturesPath = context?.filesDir
                    val dir = File(picturesPath, "pictures")
                    dir.mkdirs()
                    val filename = picture.toString().md5()
                    val file = File(dir, filename)
                    FileOutputStream(file).use {
                        val b = ByteBuffer.allocate(picture.byteCount)
                        picture.copyPixelsToBuffer(b)
                        it.write(b.array())
                    }
                }
            }
        }
    }

    val requestPermissionLauncher = registerForActivityResult(
        ActivityResultContracts.RequestPermission()
    ) { isGranted ->
        if (isGranted) {
            val cameraIntent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)
            startActivityForResult(cameraIntent, 200)
        } else {
            Toast.makeText(
                requireContext(),
                "I need permission for camera in order to take a picture!",
                Toast.LENGTH_LONG
            ).show()
        }
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        binding.saveButton.setOnClickListener {

        }

        binding.takePictureButton.setOnClickListener {
            requestPermissionLauncher.launch(android.Manifest.permission.CAMERA)
        }

        binding.scanButton.setOnClickListener {
            val options = GmsBarcodeScannerOptions.Builder()
                .setBarcodeFormats(
                    Barcode.FORMAT_EAN_13
                )
                .build()
            val scanner = GmsBarcodeScanning.getClient(requireContext())
            scanner.startScan()
                .addOnSuccessListener { barcode ->
                    binding.productName.setText(barcode.rawValue)
                }
                .addOnFailureListener { e ->
                    Toast.makeText(
                        requireContext(),
                        "Failed to scan barcode. Please, try again or enter data manually",
                        Toast.LENGTH_LONG
                    ).show()
                }
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}